@@ -290,41 +290,33 @@ setReplaceMethod("[", signature(x = "Matrix", i = "ANY", j = "ANY",
           })
 
 
+## The trivial methods :
+setMethod("cbind2", signature(x = "Matrix", y = "NULL"),
+          function(x, y) x)
+setMethod("cbind2", signature(x = "Matrix", y = "missing"),
+          function(x, y) x)
+setMethod("cbind2", signature(x = "NULL", y="Matrix"),
+          function(x, y) x)
 
-## NOTE: the following only works for R 2.2.x (and later) ---
-## ----  *and* 'Matrix' must have been *installed* by R >= 2.2.x
+setMethod("rbind2", signature(x = "Matrix", y = "NULL"),
+          function(x, y) x)
+setMethod("rbind2", signature(x = "Matrix", y = "missing"),
+          function(x, y) x)
+setMethod("rbind2", signature(x = "NULL", y="Matrix"),
+          function(x, y) x)
 
-if(paste(R.version$major, R.version$minor, sep=".") >= "2.2") {
+## Makes sure one gets x decent error message for the unimplemented cases:
+setMethod("cbind2", signature(x = "Matrix", y = "Matrix"),
+          function(x, y) {
+              rowCheck(x,y)
+              stop(gettextf("cbind2() method for (%s,%s) not-yet defined",
+                            class(x), class(y)))
+          })
 
-    ## The trivial methods :
-    setMethod("cbind2", signature(x = "Matrix", y = "NULL"),
-	      function(x, y) x)
-    setMethod("cbind2", signature(x = "Matrix", y = "missing"),
-	      function(x, y) x)
-    setMethod("cbind2", signature(x = "NULL", y="Matrix"),
-	      function(x, y) x)
-
-    setMethod("rbind2", signature(x = "Matrix", y = "NULL"),
-	      function(x, y) x)
-    setMethod("rbind2", signature(x = "Matrix", y = "missing"),
-	      function(x, y) x)
-    setMethod("rbind2", signature(x = "NULL", y="Matrix"),
-	      function(x, y) x)
-
-    ## Makes sure one gets x decent error message for the unimplemented cases:
-    setMethod("cbind2", signature(x = "Matrix", y = "Matrix"),
-              function(x, y) {
-                  rowCheck(x,y)
-                  stop(gettextf("cbind2() method for (%s,%s) not-yet defined",
-                                class(x), class(y)))
-              })
-
-    ## Use a working fall back {particularly useful for sparse}:
-    ## FIXME: implement rbind2 via "cholmod" for C* and Tsparse ones
-    setMethod("rbind2", signature(x = "Matrix", y = "Matrix"),
-              function(x, y) {
-                  colCheck(x,y)
-                  t(cbind2(t(x), t(y)))
-              })
-
-}## R-2.2.x and newer
+## Use a working fall back {particularly useful for sparse}:
+## FIXME: implement rbind2 via "cholmod" for C* and Tsparse ones
+setMethod("rbind2", signature(x = "Matrix", y = "Matrix"),
+          function(x, y) {
+              colCheck(x,y)
+              t(cbind2(t(x), t(y)))
+          })
