@@ -33,36 +33,21 @@ SEXP dspMatrix_norm(SEXP obj, SEXP type)
     return ScalarReal(get_norm_sp(obj, CHAR(asChar(type))));
 }
 
-static
-double set_rcond_sp(SEXP obj, char *typstr)
-{
-    char typnm[] = {'\0', '\0'};
-    SEXP rcv = GET_SLOT(obj, Matrix_rcondSym);
-    double rcond;
-
-    typnm[0] = rcond_type(typstr);
-    rcond = get_double_by_name(rcv, typnm);
-
-    if (R_IsNA(rcond)) {
-	SEXP trf = dspMatrix_trf(obj);
-	int *dims = INTEGER(GET_SLOT(obj, Matrix_DimSym)), info;
-	double anorm = get_norm_sp(obj, "O");
-
-	F77_CALL(dspcon)(uplo_P(trf), dims,
-			 REAL   (GET_SLOT(trf, Matrix_xSym)),
-			 INTEGER(GET_SLOT(trf, Matrix_permSym)),
-			 &anorm, &rcond,
-			 (double *) R_alloc(2*dims[0], sizeof(double)),
-			 (int *) R_alloc(dims[0], sizeof(int)), &info);
-	SET_SLOT(obj, Matrix_rcondSym,
-		 set_double_by_name(rcv, rcond, typnm));
-    }
-    return rcond;
-}
-
 SEXP dspMatrix_rcond(SEXP obj, SEXP type)
 {
-    return ScalarReal(set_rcond_sp(obj, CHAR(asChar(type))));
+    SEXP trf = dspMatrix_trf(obj);
+    char typnm[] = {'\0', '\0'};
+    int *dims = INTEGER(GET_SLOT(obj, Matrix_DimSym)), info;
+    double anorm = get_norm_sp(obj, "O"), rcond;
+
+    typnm[0] = rcond_type(CHAR(asChar(type)));
+    F77_CALL(dspcon)(uplo_P(trf), dims,
+		     REAL   (GET_SLOT(trf, Matrix_xSym)),
+		     INTEGER(GET_SLOT(trf, Matrix_permSym)),
+		     &anorm, &rcond,
+		     (double *) R_alloc(2*dims[0], sizeof(double)),
+		     (int *) R_alloc(dims[0], sizeof(int)), &info);
+    return ScalarReal(rcond);
 }
 
 SEXP dspMatrix_solve(SEXP a)
@@ -74,7 +59,6 @@ SEXP dspMatrix_solve(SEXP a)
     SET_SLOT(val, Matrix_uploSym, duplicate(GET_SLOT(trf, Matrix_uploSym)));
     SET_SLOT(val, Matrix_xSym, duplicate(GET_SLOT(trf, Matrix_xSym)));
     SET_SLOT(val, Matrix_DimSym, duplicate(GET_SLOT(trf, Matrix_DimSym)));
-    SET_SLOT(val, Matrix_rcondSym, duplicate(GET_SLOT(a, Matrix_rcondSym)));
     F77_CALL(dsptri)(uplo_P(val), dims, REAL(GET_SLOT(val, Matrix_xSym)),
 		     INTEGER(GET_SLOT(trf, Matrix_permSym)),
 		     (double *) R_alloc((long) dims[0], sizeof(double)),
@@ -117,8 +101,6 @@ SEXP dspMatrix_as_dsyMatrix(SEXP from)
 	dmnP = GET_SLOT(from, Matrix_DimNamesSym);
     int n = *INTEGER(dimP);
 
-    SET_SLOT(val, Matrix_rcondSym,
-	     duplicate(GET_SLOT(from, Matrix_rcondSym)));
     SET_SLOT(val, Matrix_DimSym, duplicate(dimP));
     SET_SLOT(val, Matrix_DimNamesSym, duplicate(dmnP));
     SET_SLOT(val, Matrix_uploSym, duplicate(uplo));
