@@ -20,11 +20,18 @@ stopifnot(identical(kappa(Matrix(2:5, 2)),
 
 ## also matplot() or pairs().
 
+## a regression test for  as.matrix.dist(.) still working
+stopifnot(c(43, 43) == dim(as.matrix(d <- dist(USJudgeRatings))))
+
 m <- Matrix(0:5, 3, 2)
 (m2 <- Matrix(diag(c(3,1))))
-(m3 <- crossprod(t(m)))
-### outer() works thanks to  as.array() -- up to R 2.2.1
-## Doesn't work in R-2.3.0 because the definition of outer has changed
+(m3 <- crossprod(t(m))) # <- that's an S4 method; nothing "base"
+
+svd(m)
+eigen(m3)
+
+### outer()  used to work thanks to  as.array() -- up to R 2.2.1
+##  no longer, because the definition of outer has changed
 ##stopifnot(identical(outer(m, m2),
 ##                    outer(as(m,"matrix"), as(m2,"matrix"))),
 ##          identical(outer(m3, m2),
