@@ -30,18 +30,22 @@ stopifnot(identical(exp(res)@x, exp(res@x)),
 m <- Matrix(c(0,0,2:0), 3,5)
 (mC <- as(m, "dgCMatrix"))
 sm <- sin(mC)
-stopifnot(class(sm) == class(mC),
+stopifnot(class(sm) == class(mC), class(mC) == class(mC^2),
           dim(sm) == dim(mC),
           class(0 + 100*mC) == class(mC),
           all.equal(0.1 * ((0 + 100*mC)/10), mC),
-          all.equal(sqrt(mC ^ 2), mC))
+          all.equal(sqrt(mC ^ 2), mC),
+          all.equal(m^m, mC^mC),
+          identical(mC^2, mC * mC),
+          identical(mC*2, mC + mC)
+          )
 
 x <- Matrix(rbind(0,cbind(0, 0:3,0,0,-1:2,0),0))
-x
-x + 10*t(x) # should be sparse {FIXME}
+x # sparse
+stopifnot(is(show(x + 10*t(x)), "sparseMatrix"))
 (px <- Matrix(x^x - 1))#-> sparse again
 stopifnot(px@i == c(3,4,1,4),
           px@x == c(3,26,-2,3))
 
 
-cat('Time elapsed: ', proc.time(),'\n') # "stats"
+cat('Time elapsed: ', proc.time(),'\n') # for ``statistical reasons''
